ChromeForTestingManagerError

Enum ChromeForTestingManagerError 

#[non_exhaustive]
pub enum ChromeForTestingManagerError {
Show 29 variants UnsupportedRuntime { runtime_flavor: RuntimeFlavor, }, UnsupportedPlatform, DetermineCacheDir, CreateCacheDir { cache_dir: PathBuf, }, RemoveCacheDir { cache_dir: PathBuf, }, RecreateCacheDir { cache_dir: PathBuf, }, RequestVersions { version_request: VersionRequest, }, NoMatchingVersion { version_request: VersionRequest, }, NoChromeDownload { version: Version, platform: Platform, }, NoChromedriverDownload { version: Version, platform: Platform, }, CreatePlatformDir { platform_dir: PathBuf, }, Download { artifact: ChromeForTestingArtifact, url: String, }, CreateDownloadFile { artifact: ChromeForTestingArtifact, path: PathBuf, }, WriteDownloadFile { artifact: ChromeForTestingArtifact, }, FlushDownloadFile { artifact: ChromeForTestingArtifact, }, DownloadStalled { artifact: ChromeForTestingArtifact, consecutive_stalls: u32, chunk_timeout: Duration, }, OpenDownloadedZip { path: PathBuf, }, InvalidZip { path: PathBuf, }, ZipTooLarge { path: PathBuf, size: u128, max_size: u128, }, ExtractZip { path: PathBuf, unpack_dir: PathBuf, }, RemoveDownloadedZip { path: PathBuf, }, SpawnChromedriver { path: PathBuf, }, WaitForChromedriverStartup { path: PathBuf, }, TerminateChromedriver { port: Port, }, PrepareChromeCapabilities { chrome_executable: PathBuf, }, ConfigureSessionCapabilities, StartWebDriverSession { port: Port, }, RunSessionCallback, QuitSession,
}
Error contexts reported by chrome-for-testing-manager operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsupportedRuntime

The current Tokio runtime does not support async drop cleanup.

Fields

runtime_flavor: RuntimeFlavor

The detected runtime flavor.



UnsupportedPlatform

The current platform is unsupported by chrome-for-testing.



DetermineCacheDir

The cache directory could not be determined.



CreateCacheDir

The cache directory could not be created.

Fields

cache_dir: PathBuf

The cache directory path.



RemoveCacheDir

The cache directory could not be removed.

Fields

cache_dir: PathBuf

The cache directory path.



RecreateCacheDir

The cache directory could not be recreated.

Fields

cache_dir: PathBuf

The cache directory path.



RequestVersions

The known-good version manifest could not be requested.

Fields

version_request: VersionRequest

The requested version selection.



NoMatchingVersion

No known-good version matched the requested selection.

Fields

version_request: VersionRequest

The requested version selection.



NoChromeDownload

No Chrome download exists for the selected version and platform.

Fields

version: Version

The selected Chrome version.

platform: Platform

The detected platform.



NoChromedriverDownload

No Chromedriver download exists for the selected version and platform.

Fields

version: Version

The selected Chrome version.

platform: Platform

The detected platform.



CreatePlatformDir

The platform-specific package directory could not be created.

Fields

platform_dir: PathBuf

The platform-specific package directory.



Download

The download request failed or returned a non-success status.

Fields

artifact: ChromeForTestingArtifact

The artifact being downloaded.

url: String

The download URL.



CreateDownloadFile

The downloaded archive file could not be created.

Fields

artifact: ChromeForTestingArtifact

The artifact being downloaded.

path: PathBuf

The archive path.



WriteDownloadFile

A chunk could not be written into the downloaded archive.

Fields

artifact: ChromeForTestingArtifact

The artifact being downloaded.



FlushDownloadFile

The downloaded archive file could not be flushed.

Fields

artifact: ChromeForTestingArtifact

The artifact being downloaded.



DownloadStalled

The download stalled for too long.

Fields

artifact: ChromeForTestingArtifact

The artifact being downloaded.

consecutive_stalls: u32

The number of consecutive stalls observed.

chunk_timeout: Duration

The timeout for each stall.



OpenDownloadedZip

The downloaded archive could not be opened.

Fields

path: PathBuf

The archive path.



InvalidZip

The downloaded archive was not a valid ZIP file.

Fields

path: PathBuf

The archive path.



ZipTooLarge

The downloaded archive exceeded the decompressed size safety limit.

Fields

path: PathBuf

The archive path.

size: u128

The reported decompressed size in bytes.

max_size: u128

The configured maximum decompressed size in bytes.



ExtractZip

The downloaded archive could not be extracted.

Fields

path: PathBuf

The archive path.

unpack_dir: PathBuf

The destination directory.



RemoveDownloadedZip

The downloaded archive could not be removed after extraction.

Fields

path: PathBuf

The archive path.



SpawnChromedriver

The chromedriver process could not be spawned.

Fields

path: PathBuf

The chromedriver executable path.



WaitForChromedriverStartup

Chromedriver did not report startup before the timeout.

Fields

path: PathBuf

The chromedriver executable path.



TerminateChromedriver

The chromedriver process could not be terminated.

Fields

port: Port

The chromedriver port.



PrepareChromeCapabilities

Chrome capabilities could not be prepared.

Fields

chrome_executable: PathBuf

The Chrome executable path.



ConfigureSessionCapabilities

User-provided capability setup failed.



StartWebDriverSession

The WebDriver session could not be started.

Fields

port: Port

The chromedriver port.



RunSessionCallback

User-provided session callback returned an error.



QuitSession

The WebDriver session could not be closed.