GracefulShutdownBuilder

Struct GracefulShutdownBuilder 

pub struct GracefulShutdownBuilder<State> { /* private fields */ }
Typestate builder for GracefulShutdown. Created via GracefulShutdown::builder.

Both unix and windows must be called (in that order) before build becomes available. The setter for the platform that does not match the current target accepts its argument without using it, so cross-platform code can build a value without cfg gates.