pub struct LoadedChromeHeadlessShellPackage { /* private fields */ }Expand description
A downloaded Chrome Headless Shell package paired with a matching ChromeDriver.
Use this when code specifically needs the headless-shell package. APIs that can operate on
either regular Chrome or Chrome Headless Shell use LoadedBrowserPackage instead.
Implementations
Sourceimpl LoadedChromeHeadlessShellPackage
impl LoadedChromeHeadlessShellPackage
Sourcepub fn chrome_headless_shell_executable(&self) -> &Path
pub fn chrome_headless_shell_executable(&self) -> &Path
Path to the cached Chrome Headless Shell executable.
Sourcepub fn chromedriver_executable(&self) -> &Path
pub fn chromedriver_executable(&self) -> &Path
Path to the cached ChromeDriver executable.