LoadedChromePackage

Struct LoadedChromePackage 

pub struct LoadedChromePackage { /* private fields */ }
A downloaded regular Chrome for Testing package paired with a matching ChromeDriver.

Use this when code specifically needs the full Chrome browser package. APIs that can operate on either regular Chrome or Chrome Headless Shell use LoadedBrowserPackage instead.

Implementations

Source

impl LoadedChromePackage

pub fn chrome_executable(&self) -> &Path

Path to the cached regular Chrome executable.

pub fn chromedriver_executable(&self) -> &Path

Path to the cached ChromeDriver executable.