pub struct ChromeForTestingManager { /* private fields */ }Implementations
Sourceimpl ChromeForTestingManager
impl ChromeForTestingManager
Sourcepub fn new() -> Result<Self, Report<ChromeForTestingManagerError>>
pub fn new() -> Result<Self, Report<ChromeForTestingManagerError>>
Errors
Returns an error if the current platform is unsupported or the cache directory cannot be determined or created.
Sourcepub async fn clear_cache(
&self,
) -> Result<(), Report<ChromeForTestingManagerError>>
pub async fn clear_cache( &self, ) -> Result<(), Report<ChromeForTestingManagerError>>
Errors
Returns an error if the cache directory cannot be deleted or re-created.