Chromedriver

Struct Chromedriver 

pub struct Chromedriver { /* private fields */ }
A wrapper struct for a spawned chromedriver process. Keep this alive until your test is complete.

Automatically terminates the spawned chromedriver process when dropped.

You can always manually call terminate, but the on-drop automation makes it much safer in quickly panicking contexts, such as tests.

Implementations

Source

impl Chromedriver

pub async fn run( version: VersionRequest, port: PortRequest, ) -> Result<Chromedriver>

Resolve, download, and launch a chromedriver process.

Errors

Returns an error if the runtime is not multithreaded, version resolution fails, the download fails, or the chromedriver process cannot be spawned.

pub async fn run_latest_stable() -> Result<Chromedriver>

Shortcut for Self::run with the latest stable channel version on any port.

Errors

See Self::run.

pub async fn run_latest_beta() -> Result<Chromedriver>

Shortcut for Self::run with the latest beta channel version on any port.

Errors

See Self::run.

pub async fn run_latest_dev() -> Result<Chromedriver>

Shortcut for Self::run with the latest dev channel version on any port.

Errors

See Self::run.

pub async fn run_latest_canary() -> Result<Chromedriver>

Shortcut for Self::run with the latest canary channel version on any port.

Errors

See Self::run.

pub async fn terminate(self) -> Result<ExitStatus, TerminationError>

Gracefully terminate the chromedriver process with default timeouts (3s each).

Errors

Returns an error if the process cannot be terminated within the timeout.

pub async fn terminate_with_timeouts( self, interrupt_timeout: Duration, terminate_timeout: Duration, ) -> Result<ExitStatus, TerminationError>

Gracefully terminate the chromedriver process with custom timeouts.

Errors

Returns an error if the process cannot be terminated within the given timeouts.