pub struct LoadedChromePackage { /* private fields */ }Expand description
A downloaded regular Chrome for Testing package paired with a matching ChromeDriver.
Use this when code specifically needs the full Chrome browser package. APIs that can operate
on either regular Chrome or Chrome Headless Shell use LoadedBrowserPackage instead.
Implementations
Sourceimpl LoadedChromePackage
impl LoadedChromePackage
Sourcepub fn chrome_executable(&self) -> &Path
pub fn chrome_executable(&self) -> &Path
Path to the cached regular Chrome executable.
Sourcepub fn chromedriver_executable(&self) -> &Path
pub fn chromedriver_executable(&self) -> &Path
Path to the cached ChromeDriver executable.