Session

Struct Session 

pub struct Session { /* private fields */ }
A browser session. Used to control the browser.

When using thirtyfour (feature), this has a Deref impl to thirtyfour::WebDriver, so this session can be seen as the driver.

Methods from Deref<Target = WebDriver>

pub fn clone_with_config(&self, config: WebDriverConfig) -> WebDriver

Clone this WebDriver keeping the session handle, but supplying a new WebDriverConfig.

This still uses the same underlying client, and still controls the same browser session, but uses a different WebDriverConfig for this instance.

This is useful in cases where you want to specify a custom poller configuration (or some other configuration option) for only one instance of WebDriver.